@@ -68,112 +68,32 @@ using namespace drawinglayer::primitive2d;
 
 namespace
 {
-    B2DPolygon lcl_CreatePolygon( B2DRectangle aBounds, bool bMirror )
-    {
-        B2DPolygon aRetval;
-        const double nRadius = 1;
-        const double nKappa((M_SQRT2 - 1.0) * 4.0 / 3.0);
-
-        // Create the top left corner
-        {
-            B2DPoint aTLCorner = aBounds.getMinimum();
-            B2DPoint aStart( 0.0, nRadius );
-            B2DPoint aEnd( nRadius, 0.0 );
-            aRetval.append( aStart );
-            aRetval.appendBezierSegment(
-                    interpolate( aStart, aTLCorner, nKappa ),
-                    interpolate( aEnd, aTLCorner, nKappa ),
-                    aEnd );
-        }
-
-        // Create the top right angle
-        {
-            B2DPoint aTMCorner( aBounds.getWidth() - ARROW_WIDTH, 0.0 );
-            B2DPoint aStart = aTMCorner + B2DVector( - nRadius, 0.0 );
-            B2DVector aEndVect( double( ARROW_WIDTH ), aBounds.getHeight() / 2.0 );
-            aEndVect.setLength( nRadius );
-            B2DPoint aEnd = aTMCorner + aEndVect;
-            aRetval.append( aStart );
-            aRetval.appendBezierSegment(
-                    interpolate( aStart, aTMCorner, nKappa ),
-                    interpolate( aEnd, aTMCorner, nKappa ),
-                    aEnd );
-        }
-
-        // Create the right corner
-        {
-            B2DPoint aMRCorner( aBounds.getWidth(), aBounds.getHeight() / 2.0 );
-            B2DVector aStartVect( double( - ARROW_WIDTH ), - aBounds.getHeight() / 2.0 );
-            aStartVect.setLength( nRadius );
-            B2DPoint aStart = aMRCorner + aStartVect;
-            B2DVector aEndVect( double( - ARROW_WIDTH ), aBounds.getHeight() / 2.0 );
-            aEndVect.setLength( nRadius );
-            B2DPoint aEnd = aMRCorner + aEndVect;
-            aRetval.append( aStart );
-            aRetval.appendBezierSegment(
-                    interpolate( aStart, aMRCorner, nKappa ),
-                    interpolate( aEnd, aMRCorner, nKappa ),
-                    aEnd );
-        }
-
-        // Create the bottom right angle
-        {
-            B2DPoint aBMCorner( aBounds.getWidth() - ARROW_WIDTH, aBounds.getHeight() );
-            B2DVector aStartVect( double( ARROW_WIDTH ), - aBounds.getHeight() / 2.0 );
-            aStartVect.setLength( nRadius );
-            B2DPoint aStart = aBMCorner + aStartVect;
-            B2DPoint aEnd = aBMCorner + B2DVector( - nRadius, 0.0 );
-            aRetval.append( aStart );
-            aRetval.appendBezierSegment(
-                    interpolate( aStart, aBMCorner, nKappa ),
-                    interpolate( aEnd, aBMCorner, nKappa ),
-                    aEnd );
-        }
-
-        // Create the bottom left corner
-        {
-            B2DPoint aBLCorner( aBounds.getMinX(), aBounds.getHeight() );
-            B2DPoint aStart( nRadius, aBounds.getHeight() );
-            B2DPoint aEnd( 0.0, aBounds.getHeight() - nRadius );
-            aRetval.append( aStart );
-            aRetval.appendBezierSegment(
-                    interpolate( aStart, aBLCorner, nKappa ),
-                    interpolate( aEnd, aBLCorner, nKappa ),
-                    aEnd );
-        }
-
-        aRetval.setClosed( true );
-
-        if ( bMirror )
-        {
-            B2DHomMatrix bRotMatrix = createRotateAroundPoint(
-                    aBounds.getCenterX(), aBounds.getCenterY(), M_PI );
-            aRetval.transform( bRotMatrix );
-        }
-
-        return aRetval;
-    }
-
     class SwBreakDashedLine : public SwDashedLine
     {
         private:
             SwPageBreakWin* m_pWin;
 
         public:
-            SwBreakDashedLine( Window* pParent, const BColor& rColor, SwPageBreakWin* pWin ) :
-                SwDashedLine( pParent, rColor ),
+            SwBreakDashedLine( Window* pParent, Color& ( *pColorFn )(), SwPageBreakWin* pWin ) :
+                SwDashedLine( pParent, pColorFn ),
                 m_pWin( pWin ) {};
 
-
             virtual void MouseMove( const MouseEvent& rMEvt );
     };
 
     void SwBreakDashedLine::MouseMove( const MouseEvent& rMEvt )
     {
-        if ( rMEvt.IsLeaveWindow() )
+        Point aEventPos( GetPosPixel() + rMEvt.GetPosPixel() );
+        if ( !m_pWin->Contains( aEventPos ) )
             m_pWin->Fade( false );
         else if ( !m_pWin->IsVisible() )
             m_pWin->Fade( true );
+
+        if ( !rMEvt.IsSynthetic() )
+        {
+            Point* pPtr = new Point( rMEvt.GetPosPixel() );
+            m_pWin->UpdatePosition( pPtr );
+        }
     }
 }
 
@@ -184,20 +104,22 @@ SwPageBreakWin::SwPageBreakWin( SwEditWin* pEditWin, const SwPageFrm* pPageFrm )
     m_pLine( NULL ),
     m_bIsAppearing( false ),
     m_nFadeRate( 100 ),
-    m_bDestroyed( false )
+    m_nDelayAppearing( 0 ),
+    m_bDestroyed( false ),
+    m_pMousePt( NULL )
 {
     // Use pixels for the rest of the drawing
     SetMapMode( MapMode ( MAP_PIXEL ) );
 
     // Create the line control
-    BColor aColor = SwViewOption::GetPageBreakColor().getBColor();
-    m_pLine = new SwBreakDashedLine( GetEditWin(), aColor, this );
+    m_pLine = new SwBreakDashedLine( GetEditWin(), &SwViewOption::GetPageBreakColor, this );
 
     // Create the popup menu
     m_pPopupMenu = new PopupMenu( SW_RES( MN_PAGEBREAK_BUTTON ) );
+    m_pPopupMenu->SetDeactivateHdl( LINK( this, SwPageBreakWin, HideHandler ) );
     SetPopupMenu( m_pPopupMenu );
 
-    m_aFadeTimer.SetTimeout( 500 );
+    m_aFadeTimer.SetTimeout( 50 );
     m_aFadeTimer.SetTimeoutHdl( LINK( this, SwPageBreakWin, FadeHandler ) );
 }
 
@@ -208,6 +130,7 @@ SwPageBreakWin::~SwPageBreakWin( )
 
     delete m_pPopupMenu;
     delete m_pLine;
+    delete m_pMousePt;
 }
 
 void SwPageBreakWin::Paint( const Rectangle& )
@@ -232,14 +155,12 @@ void SwPageBreakWin::Paint( const Rectangle& )
         aOtherColor = rSettings.GetDialogColor( ).getBColor();
     }
 
-    bool bShowOnRight = ShowOnRight( );
     bool bRtl = Application::GetSettings().GetLayoutRTL();
 
     Primitive2DSequence aSeq( 3 );
     B2DRectangle aBRect( double( aRect.Left() ), double( aRect.Top( ) ),
            double( aRect.Right() ), double( aRect.Bottom( ) ) );
-    bool bMirror = ( bShowOnRight && !bRtl ) || ( !bShowOnRight && bRtl );
-    B2DPolygon aPolygon = lcl_CreatePolygon( aBRect, bMirror );
+    B2DPolygon aPolygon = createPolygonFromRect( aBRect, 3.0 / BUTTON_WIDTH, 3.0 / BUTTON_HEIGHT );
 
     // Create the polygon primitives
     aSeq[0] = Primitive2DReference( new PolyPolygonColorPrimitive2D(
@@ -250,7 +171,7 @@ void SwPageBreakWin::Paint( const Rectangle& )
     // Create the primitive for the image
     Image aImg( SW_RES( IMG_PAGE_BREAK ) );
     double nImgOfstX = 3.0;
-    if ( bMirror )
+    if ( bRtl )
         nImgOfstX = aRect.Right() - aImg.GetSizePixel().Width() - 3.0;
     aSeq[2] = Primitive2DReference( new DiscreteBitmapPrimitive2D(
             aImg.GetBitmapEx(), B2DPoint( nImgOfstX, 1.0 ) ) );
@@ -261,7 +182,7 @@ void SwPageBreakWin::Paint( const Rectangle& )
         double nTop = double( aRect.getHeight() ) / 2.0;
         double nBottom = nTop + 4.0;
         double nLeft = aRect.getWidth( ) - ARROW_WIDTH - 6.0;
-        if ( bMirror )
+        if ( bRtl )
             nLeft = ARROW_WIDTH - 2.0;
         double nRight = nLeft + 8.0;
 
@@ -382,7 +303,8 @@ void SwPageBreakWin::Select( )
 
 void SwPageBreakWin::MouseMove( const MouseEvent& rMEvt )
 {
-    if ( rMEvt.IsLeaveWindow() )
+    Point aEventPos( rMEvt.GetPosPixel() + rMEvt.GetPosPixel() );
+    if ( !Contains( aEventPos ) && !PopupMenu::IsInExecute() )
         Fade( false );
     else if ( !IsVisible() )
         Fade( true );
@@ -394,26 +316,16 @@ void SwPageBreakWin::Activate( )
     MenuButton::Activate();
 }
 
-bool SwPageBreakWin::ShowOnRight( )
+void SwPageBreakWin::UpdatePosition( const Point* pEvtPt )
 {
-    bool bOnRight = false;
+    if ( pEvtPt != NULL )
+    {
+        if ( pEvtPt == m_pMousePt )
+            return;
+        delete m_pMousePt;
+        m_pMousePt = pEvtPt;
+    }
 
-    // Handle the book mode / columns view case
-    const SwViewOption* pViewOpt = GetEditWin()->GetView().GetWrtShell().GetViewOptions();
-    bool bBookMode = pViewOpt->IsViewLayoutBookMode();
-
-    if ( bBookMode )
-        bOnRight = GetPageFrame()->SidebarPosition( ) == sw::sidebarwindows::SIDEBAR_RIGHT;
-
-    // Handle the RTL case
-    if ( !bBookMode && Application::GetSettings().GetLayoutRTL() )
-        bOnRight = !bOnRight;
-
-    return bOnRight;
-}
-
-void SwPageBreakWin::UpdatePosition( )
-{
     const SwPageFrm* pPageFrm = GetPageFrame();
     const SwFrm* pPrevPage = pPageFrm->GetPrev();
     while ( pPrevPage && ( pPrevPage->Frm().Top( ) == pPageFrm->Frm().Top( ) ) )
@@ -450,24 +362,20 @@ void SwPageBreakWin::UpdatePosition( )
 
     long nLineLeft = std::max( nPgLeft, aVisArea.Left() );
     long nLineRight = std::min( nPgRight, aVisArea.Right() );
-    long nBtnLeft = nPgLeft;
+    long nBtnLeft = nLineLeft;
 
-    if ( ShowOnRight( ) )
+    if ( m_pMousePt )
     {
-        long nRight = std::min( nPgRight + aBtnSize.getWidth() - ARROW_WIDTH / 2, aVisArea.Right() );
-        nBtnLeft = nRight - aBtnSize.getWidth();
-        if ( IsVisible() )
-           nLineRight = nBtnLeft - ARROW_WIDTH / 2;
-    }
-    else
-    {
-        nBtnLeft = std::max( nPgLeft - aBtnSize.Width() + ARROW_WIDTH / 2, aVisArea.Left() );
-        if ( IsVisible() )
-           nLineLeft = nBtnLeft + aBtnSize.Width( ) + ARROW_WIDTH / 2;
+        nBtnLeft = nLineLeft + m_pMousePt->X() - aBtnSize.getWidth() / 2;
+
+        if ( nBtnLeft < nLineLeft )
+            nBtnLeft = nLineLeft;
+        else if ( ( nBtnLeft + aBtnSize.getWidth() ) > nLineRight )
+            nBtnLeft = nLineRight - aBtnSize.getWidth();
     }
 
     // Set the button position
-    Point aBtnPos( nBtnLeft, nYLineOffset - aBtnSize.Height() / 2 );
+    Point aBtnPos( nBtnLeft, nYLineOffset - BUTTON_HEIGHT / 2 );
     SetPosSizePixel( aBtnPos, aBtnSize );
 
     // Set the line position
@@ -481,6 +389,19 @@ void SwPageBreakWin::ShowAll( bool bShow )
     m_pLine->Show( bShow );
 }
 
+bool SwPageBreakWin::Contains( const Point &rDocPt ) const
+{
+    Rectangle aRect( GetPosPixel(), GetSizePixel() );
+    if ( aRect.IsInside( rDocPt ) )
+        return true;
+
+    Rectangle aLineRect( m_pLine->GetPosPixel(), m_pLine->GetSizePixel() );
+    if ( aLineRect.IsInside( rDocPt ) )
+        return true;
+
+    return false;
+}
+
 const SwPageFrm* SwPageBreakWin::GetPageFrame( )
 {
     return static_cast< const SwPageFrm * >( GetFrame( ) );
@@ -493,22 +414,37 @@ void SwPageBreakWin::SetReadonly( bool bReadonly )
 
 void SwPageBreakWin::Fade( bool bFadeIn )
 {
-    if ( !PopupMenu::IsInExecute() )
-    {
-        m_bIsAppearing = bFadeIn;
-        if ( !m_bDestroyed && m_aFadeTimer.IsActive( ) )
-            m_aFadeTimer.Stop();
-        if ( !m_bDestroyed )
-            m_aFadeTimer.Start( );
-    }
+    m_bIsAppearing = bFadeIn;
+    if ( bFadeIn )
+        m_nDelayAppearing = 0;
+
+    if ( !m_bDestroyed && m_aFadeTimer.IsActive( ) )
+        m_aFadeTimer.Stop();
+    if ( !m_bDestroyed )
+        m_aFadeTimer.Start( );
+}
+
+IMPL_LINK( SwPageBreakWin, HideHandler, void *, EMPTYARG )
+{
+    Fade( false );
+
+    return 0;
 }
 
 IMPL_LINK( SwPageBreakWin, FadeHandler, Timer *, EMPTYARG )
 {
+    const int TICKS_BEFORE_WE_APPEAR = 10;
+    if ( m_bIsAppearing && m_nDelayAppearing < TICKS_BEFORE_WE_APPEAR )
+    {
+        ++m_nDelayAppearing;
+        m_aFadeTimer.Start();
+        return 0;
+    }
+
     if ( m_bIsAppearing && m_nFadeRate > 0 )
-        m_nFadeRate -= 10;
+        m_nFadeRate -= 25;
     else if ( !m_bIsAppearing && m_nFadeRate < 100 )
-        m_nFadeRate += 10;
+        m_nFadeRate += 25;
 
     if ( m_nFadeRate != 100 && !IsVisible() )
         Show();
@@ -520,20 +456,8 @@ IMPL_LINK( SwPageBreakWin, FadeHandler, Timer *, EMPTYARG )
         Invalidate();
     }
 
-    if ( IsVisible( ) )
-    {
-        if ( m_nFadeRate > 0 )
-            m_aFadeTimer.SetTimeout( 100 );
-        else
-        {
-            m_aFadeTimer.SetTimeout( 3000 );
-        }
-
-        if ( m_nFadeRate > 0 && m_nFadeRate < 100 )
-            m_aFadeTimer.Start();
-    }
-    else
-        m_aFadeTimer.SetTimeout( 500 );
+    if ( IsVisible( ) && m_nFadeRate > 0 && m_nFadeRate < 100 )
+        m_aFadeTimer.Start();
 
     return 0;
 }
